@@ -185,9 +185,13 @@ getKeysPresent = do
 	getKeysPresent' $ annexObjectDir g
 getKeysPresent' :: FilePath -> Annex [Key]
 getKeysPresent' dir = do
-	contents <- liftIO $ getDirectoryContents dir
-	files <- liftIO $ filterM present contents
-	return $ map fileKey files
+	exists <- liftIO $ doesDirectoryExist dir
+	if (not exists)
+		then return []
+		else do
+			contents <- liftIO $ getDirectoryContents dir
+			files <- liftIO $ filterM present contents
+			return $ map fileKey files
 	where
 		present d = do
 			result <- try $
@@ -200,6 +204,6 @@ getKeysPresent' dir = do
 getKeysReferenced :: Annex [Key]
 getKeysReferenced = do
 	g <- Annex.gitRepo
-	files <- liftIO $ Git.inRepo g $ Git.workTree g
+	files <- liftIO $ Git.inRepo g [Git.workTree g]
 	keypairs <- mapM Backend.lookupFile files
 	return $ map fst $ catMaybes keypairs
